#include "EventGeneratorBase.h"
#include "Events/EventRouter.h"

void
EventGeneratorBase::DoStart() {
	BehaviorBase::DoStart();
	if(autoListen)
		erouter->addListener(this,getListenGeneratorID(),getListenSourceID());
}

void
EventGeneratorBase::DoStop() {
	erouter->removeListener(this);
	BehaviorBase::DoStop();
}

/*! @file
 * @brief 
 * @author ejt (Creator)
 *
 * $Author: ejt $
 * $Name: tekkotsu-2_2 $
 * $Revision: 1.2 $
 * $State: Exp $
 * $Date: 2004/10/07 19:07:05 $
 */

